==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RateLimitAdminNotifications.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ RateLimitAdminNotifications.JSON_PROPERTY_NOTIFICATIONS_ENABLED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class RateLimitAdminNotifications implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NOTIFICATIONS_ENABLED = "notificationsEnabled";
    private Boolean notificationsEnabled;

    public RateLimitAdminNotifications() {
    }

    public RateLimitAdminNotifications notificationsEnabled(Boolean notificationsEnabled) {

        this.notificationsEnabled = notificationsEnabled;
        return this;
    }

    /**
     * Get notificationsEnabled
     *
     * @return notificationsEnabled
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_NOTIFICATIONS_ENABLED)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public Boolean getNotificationsEnabled() {
        return notificationsEnabled;
    }

    @JsonProperty(JSON_PROPERTY_NOTIFICATIONS_ENABLED)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setNotificationsEnabled(Boolean notificationsEnabled) {
        this.notificationsEnabled = notificationsEnabled;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RateLimitAdminNotifications rateLimitAdminNotifications = (RateLimitAdminNotifications) o;
        return Objects.equals(this.notificationsEnabled, rateLimitAdminNotifications.notificationsEnabled);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(notificationsEnabled);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RateLimitAdminNotifications {\n");
        sb.append("    notificationsEnabled: ").append(toIndentedString(notificationsEnabled)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RateLimitAdminNotifications.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
*
*/
@ApiModel(description = "")
@JsonPropertyOrder({ RateLimitAdminNotifications.JSON_PROPERTY_NOTIFICATIONS_ENABLED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class RateLimitAdminNotifications implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_NOTIFICATIONS_ENABLED = "notificationsEnabled";
    private Boolean notificationsEnabled;

    public RateLimitAdminNotifications() {
    }

    public RateLimitAdminNotifications notificationsEnabled(Boolean notificationsEnabled) {

        this.notificationsEnabled = notificationsEnabled;
        return this;
    }

    /**
     * Get notificationsEnabled
     *
     * @return notificationsEnabled
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_NOTIFICATIONS_ENABLED)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public Boolean getNotificationsEnabled() {
        return notificationsEnabled;
    }

    @JsonProperty(JSON_PROPERTY_NOTIFICATIONS_ENABLED)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setNotificationsEnabled(Boolean notificationsEnabled) {
        this.notificationsEnabled = notificationsEnabled;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RateLimitAdminNotifications rateLimitAdminNotifications = (RateLimitAdminNotifications) o;
        return Objects.equals(this.notificationsEnabled, rateLimitAdminNotifications.notificationsEnabled);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(notificationsEnabled);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RateLimitAdminNotifications {\n");
        sb.append("    notificationsEnabled: ").append(toIndentedString(notificationsEnabled)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
